@@ -4,9 +4,9 @@
  * GChemPaint library
  * application.cc 
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,19 +20,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
-
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 #include "gchempaint-config.h"
 #include "application.h"
 #include "document.h"
@@ -54,17 +55,13 @@
 #include <libgnomevfs/gnome-vfs-mime.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <sstream>
-
-enum gcpFileTypes
-{
-	gcp_ft_Normal = 1,
-	gcp_ft_CML,
-	gcp_ft_SDF,
-	gcp_ft_PDB,
-	gcp_ft_ChemDraw,
-	gcp_ft_max
-};
+#include <locale.h>
+#ifdef HAS_OPENBABEL_2
+#	include <mol.h>
+#	include <obconversion.h>
+#else
+#	include <sstream>
+#endif
 
 // Objects creation static methods
 static Object* CreateMolecule()
@@ -102,6 +99,11 @@ static Object* CreateMesomeryArrow()
 	return new gcpMesomeryArrow(NULL);
 }
 
+static Object* CreateMesomer ()
+{
+	return new gcpMesomer ();
+}
+
 static Object* CreateText()
 {
 	return new gcpText();
@@ -114,7 +116,6 @@ static Object* CreateFragment()
 
 list<gcpApplication*> Apps;
 bool	gcpApplication::m_bInit = false;
-bool	gcpApplication::m_Have_ps2eps = false;
 bool	gcpApplication::m_Have_Ghemical = false;
 map<string, string> gcpApplication::m_SupportedPixbufFormats;
 
@@ -179,19 +180,16 @@ gcpApplication::gcpApplication ()
 
 	if (!m_bInit) {
 		// Check for programs
-		char *result = NULL;;
-		// check for ps2eps
-		m_Have_ps2eps = (g_spawn_command_line_sync ("which ps2eps", &result, NULL, NULL, NULL)
-			&& result && strlen (result));
-		if (result) {
-			g_free (result);
-			result = NULL;
-		}
+		char *result = NULL, *errors = NULL;
 		// check for ghemical
-		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, NULL, NULL, NULL)
+		m_Have_Ghemical = (g_spawn_command_line_sync ("which ghemical", &result, &errors, NULL, NULL)
 			&& result && strlen (result));
 		if (result)
 			g_free (result);
+		if (errors) {
+			g_free (errors);
+			errors = NULL;
+		}
 		// check supported pixbuf formats
 		GSList *formats = gdk_pixbuf_get_formats ();
 		GSList *l = formats;
@@ -218,7 +216,7 @@ gcpApplication::gcpApplication ()
 		ReactionStepType = Object::AddType ("reaction-step", CreateReactionStep);
 		Object::AddType ("reactant", CreateReactant, ReactantType);
 		Object::AddType("reaction-arrow", CreateReactionArrow, ReactionArrowType);
-		MesomerType = Object::AddType ("mesomer", NULL);
+		MesomerType = Object::AddType ("mesomer", CreateMesomer);
 		Object::AddType ("mesomery", CreateMesomery, MesomeryType);
 		Object::SetCreationLabel (MesomeryType, _("Create a new mesomery relationship"));
 		Object::AddType("mesomery-arrow", CreateMesomeryArrow, MesomeryArrowType);
@@ -432,6 +430,13 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 		}
 		if (result == GTK_RESPONSE_YES)
 		{
+#ifdef HAS_OPENBABEL_2
+			pDoc->SetType (filetype);
+			if (filetype == gcp_ft_Normal)
+				SaveGcp (filename2, pDoc);
+			else
+				SaveWithBabel (filename2, ext, pDoc, filetype);
+#else
 			switch(filetype)
 			{
 				case gcp_ft_Normal:
@@ -443,6 +448,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 				case gcp_ft_PDB: SaveWithBabel(filename2, ext, pDoc, PDB); break;
 				case gcp_ft_ChemDraw: SaveWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
 			}
+#endif
 		}
 	}
 	else //loading
@@ -510,6 +516,12 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			}
 		}
 		else filename2 = g_strdup(filename);
+#ifdef HAS_OPENBABEL_2
+		if (filetype == gcp_ft_Normal)
+			OpenGcp (filename2, pDoc);
+		else
+			OpenWithBabel (filename2, ext, pDoc, filetype);
+#else
 		switch (filetype)
 		{
 			case gcp_ft_Normal: OpenGcp(filename2, pDoc); break;
@@ -518,6 +530,7 @@ bool gcpApplication::FileProcess(const gchar* filename, int filetype, bool bSave
 			case gcp_ft_PDB: OpenWithBabel(filename2, ext, pDoc, PDB); break;
 			case gcp_ft_ChemDraw: OpenWithBabel(filename2, ext, pDoc, CHEMDRAW); break;
 		}
+#endif
 	}
 	g_free(filename2);
 	return false;
@@ -553,9 +566,17 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			if (!ifs) throw (int) 1;
 			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 			setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+			OBMol Mol;
+			OBConversion Conv;
+			OBFormat* pInFormat = Conv.FormatFromExt (filename);
+			Conv.SetInAndOutFormats (pInFormat, pInFormat);
+			Conv.Read (&Mol, &ifs);
+#else
 			OBMol Mol ((io_type) Type);
 			OBFileFormat fileFormat;
 			fileFormat.ReadMolecule (ifs, Mol);
+#endif
 			result = pDoc->ImportOB(Mol);
 			setlocale (LC_NUMERIC, old_num_locale);
 			g_free (old_num_locale);
@@ -568,9 +589,17 @@ void gcpApplication::OpenWithBabel(const gchar* filename, const gchar* ext, gcpD
 			istringstream iss (buf);
 			old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
 			setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+			OBMol Mol;
+			OBConversion Conv;
+			OBFormat* pInFormat = Conv.FormatFromExt (filename);
+			Conv.SetInAndOutFormats (pInFormat, pInFormat);
+			Conv.Read (&Mol, &iss);
+#else
 			OBMol Mol ((io_type) Type);
 			OBFileFormat fileFormat;
 			fileFormat.ReadMolecule (iss, Mol);
+#endif
 			result = pDoc->ImportOB(Mol);
 			setlocale (LC_NUMERIC, old_num_locale);
 			setlocale (LC_NUMERIC, old_num_locale);
@@ -803,8 +832,8 @@ void gcpApplication::OnSaveAsImage ()
 	for (i = m_SupportedPixbufFormats.begin (); i != end; i++)
 		gtk_file_filter_add_mime_type (filter, (*i).first.c_str ());
 	gtk_file_filter_add_mime_type (filter, "image/svg+xml");
-	if (m_Have_ps2eps)
-		gtk_file_filter_add_mime_type (filter, "image/x-eps");
+	gtk_file_filter_add_mime_type (filter, "image/x-eps");
+	gtk_file_filter_add_mime_type (filter, "image/x-xfig");
 	gtk_file_chooser_set_filter (dialog, filter);
 	while (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT) {
 		filename = gtk_file_chooser_get_filename (dialog);
@@ -834,21 +863,11 @@ void gcpApplication::OnSaveAsImage ()
 		const char* mime_type = gnome_vfs_mime_type_from_name (filename);
 		if (m_SupportedPixbufFormats.find (mime_type) != m_SupportedPixbufFormats.end())
 			m_pActiveDoc->ExportImage (filename, m_SupportedPixbufFormats[mime_type].c_str ());
-		else if (!strcmp (mime_type, "image/x-eps")) {
-			if (m_Have_ps2eps)
+		else if (!strcmp (mime_type, "image/x-eps"))
 				m_pActiveDoc->ExportImage (filename, "eps");
-			else {
-				GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-																	"Can't export eps files, please install ps2eps");
-				gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
-				gtk_dialog_run (GTK_DIALOG (message));
-				gtk_widget_destroy (message);
-			}
-		}
 		else if (!strcmp (mime_type, "image/svg+xml")) {
 			m_pActiveDoc->ExportImage (filename, "svg");
-		}
-		else {
+		} else {
 			GtkWidget* message = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
 																_("Sorry, format not supported!"));
 			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
