@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -78,6 +78,9 @@ public:
 	void OnShowElements ();
 	void OnSaveAsImage ();
 	bool HaveGhemical () {return m_Have_Ghemical;}
+	char const* GetCurDir () {return CurDir;}
+	void SetCurDir (char const* dir);
+	int GetDocsNumber () {return m_Docs.size ();}
 
 protected:
 	virtual void AddDocument(gcpDocument* pDoc) = 0;
@@ -97,7 +100,7 @@ protected:
 	map <string, gcpDialog*> Dialogs;
 	map <string, GCallback> Callbacks;
 	gcpTool* m_pActiveTool;
-	static bool m_bInit, m_Have_ps2eps, m_Have_Ghemical;
+	static bool m_bInit, m_Have_Ghemical;
 	static map<string, string> m_SupportedPixbufFormats;
 	BonoboUINode* m_pNode;
 	char *FontName;
@@ -106,6 +109,7 @@ protected:
 	string WebBrowser;
 	string MailAgent;
 	xmlDocPtr XmlDoc;
+	char *CurDir;
 };
 
 extern list<gcpApplication*> Apps;
