@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -66,7 +66,7 @@ gcpAtom::gcpAtom(): Atom()
 	m_Changed = 0;
 	m_AvailPosCached = false;
 	m_OccupiedPos = 0;
-	m_ChargePos = -1;
+	m_ChargePos = 0xff;
 	m_ChargeAngle = 0.;
 	m_ChargeDist = 0.;
 }
@@ -98,7 +98,7 @@ gcpAtom::gcpAtom(int Z, double x, double y, double z): Atom(Z, x, y, z)
 	m_Changed = 0;
 	m_AvailPosCached = false;
 	m_OccupiedPos = 0;
-	m_ChargePos = -1;
+	m_ChargePos = 0xff;
 	m_ChargeAngle = 0.;
 	m_ChargeDist = 0.;
 }
@@ -121,7 +121,7 @@ gcpAtom::gcpAtom(OBAtom* atom, double zoom): Atom()
 	m_Changed = 0;
 	m_AvailPosCached = false;
 	m_OccupiedPos = 0;
-	m_ChargePos = -1;
+	m_ChargePos = 0xff;
 	m_ChargeAngle = 0.;
 	m_ChargeDist = 0.;
 }
@@ -146,6 +146,8 @@ void gcpAtom::SetZ(int Z)
 	case 18:
 		if (!diff)
 			m_ValenceOrbitals = 6;
+		else
+			m_ValenceOrbitals = 4;
 		break;
 	case 32:
 		if (!diff)
@@ -159,6 +161,7 @@ void gcpAtom::SetZ(int Z)
 		m_ValenceOrbitals = 0; //should not occur
 	}
 	Update();
+	EmitSignal (OnChangedSignal);
 }
 
 int gcpAtom::GetTotalBondsNumber()
@@ -678,13 +681,13 @@ void gcpAtom::UpdateAvailablePositions ()
 	m_AvailPosCached = true;
 }
 
-int gcpAtom::GetChargePosition(char& Pos, double Angle, double& x, double& y)
+int gcpAtom::GetChargePosition(unsigned char& Pos, double Angle, double& x, double& y)
 {
 	list<double>::iterator n;
 	double angle;
 	if (!m_AvailPosCached)
 		UpdateAvailablePositions ();
-	if (Pos == -1) {
+	if (Pos == 0xff) {
 		if (m_AvailPos) {
 			if (m_AvailPos & CHARGE_NE)
 				Pos = CHARGE_NE;
@@ -1145,7 +1148,7 @@ void gcpAtom::AddElectron (gcpElectron* electron)
 	Update ();
 }
 
-void gcpAtom::NotifyPositionOccupation (char pos, bool occupied)
+void gcpAtom::NotifyPositionOccupation (unsigned char pos, bool occupied)
 {
 	if (occupied)
 		m_OccupiedPos |= pos;
@@ -1231,7 +1234,7 @@ bool gcpAtom::Load (xmlNodePtr node)
 		child = child->next;
 	}
 	char *buf = (char*) xmlGetProp (node, (xmlChar*) "charge-position");
-	m_ChargePos = -1;
+	m_ChargePos = 0xff;
 	if (buf) {
 		if (! strcmp (buf, "ne")) {
 			m_ChargePos = CHARGE_NE;
@@ -1295,7 +1298,7 @@ bool gcpAtom::AcceptCharge (int charge) {
 	return (charge <= GetZ ());
 }
 
-void gcpAtom::SetChargePosition (char Pos, bool def, double angle, double distance)
+void gcpAtom::SetChargePosition (unsigned char Pos, bool def, double angle, double distance)
 {
 	m_ChargeAutoPos = def;
 	if (m_ChargePos > 0)
