@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -575,3 +575,11 @@ void gcpBond::Update(GtkWidget* w)
 	g_object_set (obj, "bpath", path, NULL);
 	gnome_canvas_path_def_unref (path);
 }
+	
+double gcpBond::GetYAlign ()
+{
+	double x1, y1, x2, y2;
+	m_Begin->GetCoords(&x1, &y1);
+	m_End->GetCoords(&x2, &y2);
+	return (y1 + y2) / 2;
+}
