@@ -20,19 +20,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
-
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 #include "gchempaint-config.h"
 #include "application.h"
 #include "view.h"
@@ -48,8 +49,12 @@
 #include <gtk/gtk.h>
 #include <libgnomevfs/gnome-vfs-file-info.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
-#include <iostream>
-#include <sstream>
+#ifdef HAS_OPENBABEL_2
+#	include <mol.h>
+#	include <obconversion.h>
+#else
+#	include <sstream>
+#endif
 
 using namespace OpenBabel;
 using namespace std;
@@ -67,7 +72,11 @@ gcpDocument::gcpDocument(gcpApplication *App, bool StandAlone): Document()
 	m_pView = new gcpView(this, !StandAlone);
 	m_bDirty = m_bIsLoading = m_bUndoRedo = false;
 	m_bWriteable = true;
+#ifdef HAS_OPENBABEL_2
+	m_FileType = gcp_ft_Normal;
+#else
 	m_FileType = UNDEFINED;
+#endif
 	m_DocPropDlg = NULL;
 	g_date_set_time(&CreationDate, time(NULL));
 	g_date_clear(&RevisionDate, 1);
@@ -260,7 +269,11 @@ void gcpDocument::BuildAtomTable(map<string, unsigned>& AtomTable, Object* obj,
 
 void gcpDocument::ExportOB()
 {
+#ifdef HAS_OPENBABEL_2
+	OBMol Mol;
+#else
 	OBMol Mol(UNDEFINED, (io_type) m_FileType);
+#endif
 	map<string, unsigned>::iterator i;
 	map<string, unsigned> AtomTable;
 	list<gcpBond*> BondList;
@@ -316,8 +329,15 @@ void gcpDocument::ExportOB()
 			throw (int) res;
 		old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 		setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+		OBConversion Conv;
+		OBFormat* pOutFormat = Conv.FormatFromExt (m_filename);
+		Conv.SetInAndOutFormats (pOutFormat, pOutFormat);
+		Conv.Write (&Mol, &ofs);
+#else
 		OBFileFormat fileFormat;
 		fileFormat.WriteMolecule(ofs, Mol, "2D");
+#endif
 		setlocale(LC_NUMERIC, old_num_locale);
 		g_free(old_num_locale);
 		if ((res = gnome_vfs_write (handle, ofs.str ().c_str (), (GnomeVFSFileSize) ofs.str ().size (), &n)) != GNOME_VFS_OK)
@@ -466,7 +486,11 @@ void gcpDocument::AddBond(gcpBond* pBond)
 void gcpDocument::Save()
 {
 	if (!m_filename || !m_bWriteable || m_bReadOnly) return;
+#ifdef HAS_OPENBABEL_2
+	if (m_FileType != gcp_ft_Normal)
+#else
 	if (m_FileType != UNDEFINED)
+#endif
 	{
 		ExportOB();
 	}
@@ -495,7 +519,11 @@ bool gcpDocument::Load (xmlNodePtr root)
 	}
 	g_date_clear (&CreationDate, 1);
 	g_date_clear (&RevisionDate, 1);
+#ifdef HAS_OPENBABEL_2
+	m_FileType = gcp_ft_Normal;
+#else
 	m_FileType = UNDEFINED;
+#endif
 	xmlNodePtr node, child;
 	char* tmp;
 	Object* pObject;
@@ -854,7 +882,10 @@ void gcpDocument::Remove(Object* pObject)
 void gcpDocument::Remove(const char* Id)
 {
 	Object* pObj = GetDescendant(Id);
-	if (pObj) Remove(pObj);
+	if (pObj) {
+		pObj->Lock ();
+		Remove(pObj);
+	}
 }
 
 void gcpDocument::OnProperties()
@@ -918,6 +949,7 @@ void gcpDocument::OnUndo()
 	m_pApp->ActivateMenu ("Image", HasChildren ());
 	m_bUndoRedo = false;
 	Update ();
+	EmptyTranslationTable ();
 }
 
 void gcpDocument::OnRedo()
@@ -936,6 +968,7 @@ void gcpDocument::OnRedo()
 		m_pApp->ActivateMenu("Redo", false);
 	m_pApp->ActivateMenu ("Image", HasChildren ());
 	m_bUndoRedo = false;
+	EmptyTranslationTable ();
 }
 
 void gcpDocument::FinishOperation()
@@ -1030,7 +1063,7 @@ void gcpDocument::LoadObjects(xmlNodePtr node)
 			child1 = (strcmp((const char*)child->name, "object"))? child: child->children;
 			str = (const char*)child1->name;
 			Object* pObject = Object::CreateObject(str, this);
-			pObject->Load(child1); 
+			pObject->Load(child1);
 			AddObject(pObject);
 			m_pView->Update(pObject);//FIXME: should not be necessary, but solve problem with cyclic double bonds
 			m_bIsLoading = false;
@@ -1104,3 +1137,17 @@ void gcpDocument::SetReadOnly (bool ro)
 		m_pApp->ActivateToolItem ("Save", !ro);
 	}
 }
+
+double gcpDocument::GetYAlign ()
+{
+	if (GetChildrenNumber () == 1) {
+		map<string, Object*>::iterator i;
+		Object *Child = GetFirstChild (i);
+		return Child->GetYAlign ();
+	} else {
+		gcpWidgetData* pData = (gcpWidgetData*) g_object_get_data (G_OBJECT (GetWidget ()), "data");
+		ArtDRect rect;
+		pData->GetObjectBounds (this, &rect);
+		return (rect.y1 - rect.y0) / 2.;
+	}
+}
