@@ -4,7 +4,7 @@
  * GChemPaint library
  * fragment-atom.cc 
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -102,8 +102,8 @@ xmlNodePtr gcpFragmentAtom::Save(xmlDocPtr xml)
 		snprintf(buf, sizeof(buf), "%d", m_Charge);
 		xmlNewProp(node, (xmlChar*)"charge", (xmlChar*)buf);
 		double Angle, Dist;
-		char ChargePos = gcpAtom::GetChargePosition (&Angle, &Dist);
-		if (ChargePos != -1) {
+		unsigned char ChargePos = gcpAtom::GetChargePosition (&Angle, &Dist);
+		if (ChargePos != 0xff) {
 			char *buf;
 			if (ChargePos) {
 				switch (ChargePos) {
@@ -152,7 +152,8 @@ xmlNodePtr gcpFragmentAtom::Save(xmlDocPtr xml)
 
 bool gcpFragmentAtom::Load (xmlNodePtr node)
 {
-	char* buf, ChargePos = -1;
+	char* buf;
+	unsigned char ChargePos = 0xff;
 	double Angle = 0., Dist = 0.;
 	xmlNodePtr child;
 	buf = (char*) xmlGetProp (node, (xmlChar*) "id");
@@ -212,7 +213,7 @@ bool gcpFragmentAtom::Load (xmlNodePtr node)
 			sscanf (buf, "%lg", &Dist);
 			xmlFree (buf);
 		}
-		SetChargePosition (ChargePos, ChargePos == -1, Angle, Dist);
+		SetChargePosition (ChargePos, ChargePos == 0xff, Angle, Dist);
 	}
 	return true;
 }
@@ -222,7 +223,7 @@ void gcpFragmentAtom::AddToMolecule(gcpMolecule* Mol)
 	Mol->AddFragment(m_Fragment);
 }
 
-int gcpFragmentAtom::GetChargePosition(char& Pos, double Angle, double& x, double& y)
+int gcpFragmentAtom::GetChargePosition(unsigned char& Pos, double Angle, double& x, double& y)
 {
 	return m_Fragment->GetChargePosition(this, Pos, Angle, x, y);
 }
