@@ -4,7 +4,7 @@
  * GChemPaint library
  * molecule.cc 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,19 +20,20 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
-#include <mol.h>
-#undef PACKAGE
-#undef PACKAGE_BUGREPORT
-#undef PACKAGE_NAME
-#undef PACKAGE_STRING
-#undef PACKAGE_TARNAME
-#undef PACKAGE_VERSION
-#undef VERSION
-
+#ifndef HAS_OPENBABEL_2
+#	include <mol.h>
+#	undef PACKAGE
+#	undef PACKAGE_BUGREPORT
+#	undef PACKAGE_NAME
+#	undef PACKAGE_STRING
+#	undef PACKAGE_TARNAME
+#	undef PACKAGE_VERSION
+#	undef VERSION
+#endif
 #include "gchempaint-config.h"
 #include "molecule.h"
 #include "document.h"
@@ -41,6 +42,11 @@
 #include "tool.h"
 #include <math.h>
 #include <unistd.h>
+#include <locale.h>
+#ifdef HAS_OPENBABEL_2
+#	include <mol.h>
+#	include <obconversion.h>
+#endif
 
 static void do_export_to_ghemical (gcpMolecule* pMol)
 {
@@ -505,7 +511,14 @@ void gcpMolecule::ExportToGhemical ()
 {
 	double xav = 0., yav = 0., zf, zm;
 	unsigned n = m_Atoms.size();
+#ifdef HAS_OPENBABEL_2
+	OBMol Mol;
+	OBConversion Conv;
+	OBFormat* pOutFormat = Conv.FormatFromExt ("gpr");
+	Conv.SetInAndOutFormats (pOutFormat, pOutFormat);
+#else
 	OBMol Mol(UNDEFINED, GHEMICAL);
+#endif
 	map<string, unsigned> AtomTable;
 	list<gcpAtom*>::iterator ia, enda = m_Atoms.end ();
 	list<gcpBond*> BondList;
@@ -568,8 +581,12 @@ void gcpMolecule::ExportToGhemical ()
 	if (!ofs) throw (int) 1;
 	old_num_locale = g_strdup(setlocale(LC_NUMERIC, NULL));
 	setlocale(LC_NUMERIC, "C");
+#ifdef HAS_OPENBABEL_2
+	Conv.Write (&Mol, &ofs);
+#else
 	OBFileFormat fileFormat;
 	fileFormat.WriteMolecule(ofs, Mol, "3D");
+#endif
 	setlocale(LC_NUMERIC, old_num_locale);
 	g_free(old_num_locale);
 	ofs.close();
