@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -39,6 +39,25 @@ gcpReaction::gcpReaction (): Object (ReactionType)
 
 gcpReaction::~gcpReaction ()
 {
+	if (IsLocked ())
+		return;
+	map<string, Object*>::iterator i;
+	Object *pObj;
+	gcpReactionArrow *arrow;
+	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (GetDocument ());
+	gcpOperation *pOp = pDoc->GetCurrentOperation ();
+	while (pObj = GetFirstChild (i)) {
+		if (pObj->GetType () == ReactionArrowType) {
+			arrow = reinterpret_cast<gcpReactionArrow*> (pObj);
+			arrow->SetStartStep (NULL);
+			arrow->SetEndStep (NULL);
+			arrow->SetParent (GetParent ());
+			if (pOp)
+				pOp->AddObject (arrow, 1);
+			
+		} else
+			delete pObj;
+	}
 }
 
 void gcpReaction::Add (GtkWidget* w)
@@ -201,7 +220,7 @@ void gcpReaction::Transform2D (Matrix2D& m, double x, double y)
 
 bool gcpReaction::OnSignal (SignalId Signal, Object *Obj)
 {
-	if (m_IsLoading)
+	if (IsLocked ())
 		return false;
 	if (Signal == OnChangedSignal) {
 		gcpDocument *pDoc = (gcpDocument*) GetDocument ();
@@ -305,7 +324,7 @@ bool gcpReaction::Load (xmlNodePtr node)
 	Object* pObject;
 	list<xmlNodePtr> arrows;
 
-	m_IsLoading = true;
+	Lock ();
 	tmp = xmlGetProp (node, (xmlChar*) "id");
 	if (tmp) {
 		SetId ((char*) tmp);
@@ -321,7 +340,7 @@ bool gcpReaction::Load (xmlNodePtr node)
 				if (!pObject->Load (child))
 					delete pObject;
 			} else {
-				m_IsLoading = false;
+				Lock (false);
 				return false;
 			}
 		}
@@ -334,11 +353,50 @@ bool gcpReaction::Load (xmlNodePtr node)
 			if (!pObject->Load (child))
 				delete pObject;
 		} else {
-			m_IsLoading = false;
+			Lock (false);
 			return false;
 		}
 		arrows.pop_back ();
 	}
-	m_IsLoading = false;
+	Lock (false);
 	return true;
 }
+
+static void do_destroy_reaction (void *data)
+{
+	gcpReaction *reaction = reinterpret_cast<gcpReaction *> (data);
+	gcpDocument *pDoc = reinterpret_cast<gcpDocument *> (reaction->GetDocument ());
+	gcpWidgetData *pData = reinterpret_cast<gcpWidgetData *> (g_object_get_data (G_OBJECT (pDoc->GetWidget ()), "data"));
+	pData->Unselect (reaction);
+	gcpOperation *pOp = pDoc->GetNewOperation (GCP_MODIFY_OPERATION);
+	pOp->AddObject (reaction, 0);
+	delete reaction;
+	pDoc->FinishOperation ();
+}
+
+bool gcpReaction::BuildContextualMenu (GtkUIManager *UIManager, Object *object)
+{
+	GtkActionGroup *group = gtk_action_group_new ("reaction");
+	GtkAction *action = gtk_action_new ("destroy", _("Destroy the reaction"), NULL, NULL);
+	gtk_action_group_add_action (group, action);
+	gtk_ui_manager_insert_action_group (UIManager, group, 0);
+	char buf[] = "<ui><popup><menuitem action='destroy'/></popup></ui>";
+	gtk_ui_manager_add_ui_from_string (UIManager, buf, -1, NULL);
+	GtkWidget *w = gtk_ui_manager_get_widget (UIManager, "/popup/destroy");
+	g_signal_connect_swapped (w, "activate", G_CALLBACK (do_destroy_reaction), this);
+	GetParent ()->BuildContextualMenu (UIManager, object);
+	return true;
+}
+
+double gcpReaction::GetYAlign ()
+{
+	map<string, Object*>::iterator i;
+	Object *pObj;
+	pObj = GetFirstChild (i);
+	double y = DBL_MAX, new_y;
+	while (pObj)
+		if (pObj->GetType () == ReactionStepType)
+			if ((new_y = pObj->GetYAlign ()) < y)
+				y = new_y;			
+	return y;
+}
