@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2002-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -120,15 +120,16 @@ void on_clear_data(GtkClipboard *clipboard, gcpApplication *App)
 bool gcpWidgetData::IsSelected(Object *obj)
 {
 	std::list<Object*>::iterator i;
-	Object* pMol = obj->GetMolecule();
+	Object* pGroup = obj->GetGroup ();
 	for (i = SelectedObjects.begin(); i != SelectedObjects.end(); i++)
-		if ((*i == obj) || (*i == pMol)) return true;
+		if ((*i == obj) || (*i == pGroup)) return true;
 	return false;
 }
 
 void gcpWidgetData::Unselect(Object* obj)
 {
 	SelectedObjects.remove(obj);
+	obj->SetSelected(Canvas, SelStateUnselected);
 	View->Update(obj);
 }
 
@@ -146,8 +147,10 @@ void gcpWidgetData::UnselectAll()
 
 void gcpWidgetData::SetSelected(Object* obj)
 {
-	SelectedObjects.push_front(obj);
-	obj->SetSelected(Canvas, SelStateSelected);
+	if (!IsSelected (obj)) {
+		SelectedObjects.push_front(obj);
+		obj->SetSelected(Canvas, SelStateSelected);
+	}
 }
 
 void gcpWidgetData::MoveSelectedItems(double dx, double dy)
@@ -275,7 +278,7 @@ void gcpWidgetData::SelectAll()
 			if (!IsSelected(pObject))
 				SetSelected(pObject);
 		}
-		else
+		else if (!IsSelected((*i).first))
 			SetSelected((*i).first);
 	}
 }
