@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02111-1307, USA.
  */
 /*
@@ -40,11 +40,13 @@
 static void gnome_canvas_group_ext_class_init   (GnomeCanvasGroupExtClass *class);
 static void gnome_canvas_group_ext_init         (GnomeCanvasGroupExt     *group_ext);
 static void gnome_canvas_group_ext_print       (GPrintable *gprintable, GnomePrintContext *pc);
+static void gnome_canvas_group_ext_export_svg  (GPrintable *gprintable, xmlDocPtr doc, xmlNodePtr node);
 
 static void
 gnome_canvas_group_print_init (GPrintableIface *iface)
 {
 	iface->print = gnome_canvas_group_ext_print;
+	iface->export_svg = gnome_canvas_group_ext_export_svg;
 }
 
 GType
@@ -94,17 +96,57 @@ void gnome_canvas_group_ext_print (GPrintable *printable, GnomePrintContext *pc)
 {
 	GList *list;
 	double affine[6];
+	GnomeCanvasItem *item;
 	g_return_if_fail (GNOME_IS_CANVAS_GROUP_EXT (printable));
 	for (list = GNOME_CANVAS_GROUP (printable) ->item_list; list; list = list->next) {
-		if (GNOME_IS_CANVAS_GROUP_EXT(list->data))
-			gnome_canvas_group_ext_print (G_PRINTABLE (list->data), pc);
-		else if (G_IS_PRINTABLE (list->data))
+		item = GNOME_CANVAS_ITEM (list->data);
+		if (!(item->object.flags & GNOME_CANVAS_ITEM_VISIBLE))
+			continue;
+		if (GNOME_IS_CANVAS_GROUP_EXT(item))
+			gnome_canvas_group_ext_print (G_PRINTABLE (item), pc);
+		else if (G_IS_PRINTABLE (item))
 		{
-			gnome_canvas_item_i2w_affine ((GnomeCanvasItem*)list->data, affine);
+			gnome_canvas_item_i2w_affine (item, affine);
 			gnome_print_gsave(pc);
 			gnome_print_concat(pc, affine);
-			(* G_PRINTABLE_GET_IFACE (list->data)->print) (G_PRINTABLE (list->data), pc); 
+			g_printable_print (G_PRINTABLE (item), pc); 
 			gnome_print_grestore(pc);
 		}
 	}
 }
+
+static void
+gnome_canvas_group_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodePtr node)
+{
+	GList *list;
+	double affine[6];
+	GnomeCanvasItem *item;
+	g_return_if_fail (GNOME_IS_CANVAS_GROUP_EXT (printable));
+	for (list = GNOME_CANVAS_GROUP (printable) ->item_list; list; list = list->next) {
+		item = GNOME_CANVAS_ITEM (list->data);
+		if (!(item->object.flags & GNOME_CANVAS_ITEM_VISIBLE))
+			continue;
+		if (GNOME_IS_CANVAS_GROUP_EXT(item))
+			gnome_canvas_group_ext_export_svg (G_PRINTABLE (item), doc, node);
+		else if (G_IS_PRINTABLE (item))
+		{
+			char *buf;
+			gnome_canvas_item_i2w_affine (item, affine);
+			buf = g_strdup_printf ("matrix(%g,%g,%g,%g,%g,%g)",
+									affine[0],
+									affine[1],
+									affine[2],
+									affine[3],
+									affine[4],
+									affine[5]);
+			if (strcmp (buf,"matrix(1,0,0,1,0,0)")) { 
+				xmlNodePtr child = xmlNewDocNode (doc, NULL, (const xmlChar*) "g", NULL);
+				xmlAddChild (node, child);
+				xmlNewProp (child, (const xmlChar*) "transform", (const xmlChar*) buf);
+				g_free (buf);
+				g_printable_export_svg (G_PRINTABLE (item), doc, child);
+			} else
+				g_printable_export_svg (G_PRINTABLE (item), doc, node);
+		}
+	}
+}
