@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * write to the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02111-1307, USA.
  */
 /*
@@ -35,6 +35,7 @@
  */
 
 #include "gchempaint-config.h"
+#include <math.h>
 #include "gcp-canvas-text.h"
 #include "gprintable.h"
 #include "gnome-print-pango.h"
@@ -228,10 +229,12 @@ static void
 gnome_canvas_text_ext_ensure_rendered (GnomeCanvasTextExt *text)
 {
 	double x1, y1, x2, y2;
-	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (text), &x1, &y1, &x2, &y2);
-	int w = (int) (ceil (x2) - floor (x1)) + 1, h = (int) (ceil (y2) - floor (y1)) + 1;
-	GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+	int w, h;
+	GdkPixbuf *pixbuf;
 	GnomeCanvasBuf buf;
+	gnome_canvas_item_get_bounds (GNOME_CANVAS_ITEM (text), &x1, &y1, &x2, &y2);
+	w = (int) (ceil (x2) - floor (x1)) + 1, h = (int) (ceil (y2) - floor (y1)) + 1;
+	pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 	buf.buf = gdk_pixbuf_get_pixels (pixbuf);
 	buf.rect.x0 = (int) floor (x1);
 	buf.rect.x1 = (int) ceil (x2);
