@@ -15,16 +15,17 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 #include "gchempaint-config.h"
 #define GTK_TEXT_USE_INTERNAL_UNSUPPORTED_API
 #include <gtk/gtktextlayout.h>
 #include "gnome-print-pango.h"
+#include <string.h>
 
 #ifdef GP_HAS_PANGO
 #	include <libgnomeprint/gnome-print-pango.h>
