@@ -4,9 +4,9 @@
  * GChemPaint arrows plugin
  * retrosynthesisarrow.cc
  *
- * Copyright (C) 2004
+ * Copyright (C) 2004-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -121,17 +121,16 @@ void gcpRetrosynthesisArrow::Add (GtkWidget* w)
 	y0 = m_y * pData->ZoomFactor;
 	x1 = (m_x + m_width) * pData->ZoomFactor;
 	y1 = (m_y + m_height) * pData->ZoomFactor;
-	if (m_width == 0.)
-	{
-		if (m_height == 0.) return;
-		dAngle = (m_y < 0.) ? M_PI / 2 : 1.5 * M_PI;
-	}
-	else
-	{
+	if (m_width == 0.) {
+		if (m_height == 0.)
+			return;
+		dAngle = (m_height < 0.) ? M_PI / 2 : 1.5 * M_PI;
+	} else {
 		dAngle = atan(- m_height / m_width);
-		if (m_width < 0) dAngle += M_PI;
+		if (m_width < 0)
+			dAngle += M_PI;
 	}
-	GnomeCanvasGroup* group = GNOME_CANVAS_GROUP(gnome_canvas_item_new(pData->Group, gnome_canvas_group_ext_get_type(), NULL));
+	GnomeCanvasGroup* group = GNOME_CANVAS_GROUP (gnome_canvas_item_new (pData->Group, gnome_canvas_group_ext_get_type(), NULL));
 	GnomeCanvasItem* item;
 	dx = pData->ArrowDist / 2 * sin (dAngle);
 	dy = pData->ArrowDist / 2 * cos (dAngle);
@@ -145,18 +144,18 @@ void gcpRetrosynthesisArrow::Add (GtkWidget* w)
 	gnome_canvas_path_def_moveto (path, x1 - dx - dy, y1 - dy + dx);
 	gnome_canvas_path_def_lineto (path, x1, y1);
 	gnome_canvas_path_def_lineto (path, x1 + dx - dy, y1 + dy + dx);
-	item = gnome_canvas_item_new(
+	item = gnome_canvas_item_new (
 							group,
-							gnome_canvas_bpath_ext_get_type(),
+							gnome_canvas_bpath_ext_get_type (),
 							"bpath", path,
-							"outline_color", (pData->IsSelected(this))? SelectColor: Color,
+							"outline_color", (pData->IsSelected (this))? SelectColor: Color,
 							"width_units", pData->BondWidth,
 							"cap-style", GDK_CAP_BUTT,
 							"join-style", GDK_JOIN_MITER,
 							NULL);
-	g_object_set_data(G_OBJECT(item), "object", this);
-	g_object_set_data(G_OBJECT(group), "arrow", item);
-	g_signal_connect(G_OBJECT(item), "event", G_CALLBACK(on_event), w);
+	g_object_set_data (G_OBJECT (item), "object", this);
+	g_object_set_data( G_OBJECT (group), "arrow", item);
+	g_signal_connect(G_OBJECT (item), "event", G_CALLBACK (on_event), w);
 	pData->Items[this] = group;
 }
 
@@ -169,15 +168,14 @@ void gcpRetrosynthesisArrow::Update (GtkWidget* w)
 	y0 = m_y * pData->ZoomFactor;
 	x1 = (m_x + m_width) * pData->ZoomFactor;
 	y1 = (m_y + m_height) * pData->ZoomFactor;
-	if (m_width == 0.)
-	{
-		if (m_height == 0.) return;
-		dAngle = (m_y < 0.) ? M_PI / 2 : 1.5 * M_PI;
-	}
-	else
-	{
+	if (m_width == 0.) {
+		if (m_height == 0.)
+			return;
+		dAngle = (m_height < 0.) ? M_PI / 2 : 1.5 * M_PI;
+	} else {
 		dAngle = atan (- m_height / m_width);
-		if (m_width < 0) dAngle += M_PI;
+		if (m_width < 0)
+			dAngle += M_PI;
 	}
 	dx = pData->ArrowDist / 2 * sin (dAngle);
 	dy = pData->ArrowDist / 2 * cos (dAngle);
@@ -191,7 +189,7 @@ void gcpRetrosynthesisArrow::Update (GtkWidget* w)
 	gnome_canvas_path_def_moveto (path, x1 - dx - dy, y1 - dy + dx);
 	gnome_canvas_path_def_lineto (path, x1, y1);
 	gnome_canvas_path_def_lineto (path, x1 + dx - dy, y1 + dy + dx);
-	g_object_set(G_OBJECT(g_object_get_data(G_OBJECT(group), "arrow")),
+	g_object_set (G_OBJECT (g_object_get_data (G_OBJECT (group), "arrow")),
 						"bpath", path,
 						NULL);
 }
