@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -388,6 +388,7 @@ void gcpSelectionTool::CreateGroup ()
 			delete pObj;
 			GtkWidget* message = gtk_message_dialog_new (NULL, (GtkDialogFlags) 0,
 								GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, e.what ());
+			gtk_window_set_icon_name (GTK_WINDOW (message), "gchempaint");
 			g_signal_connect_swapped (G_OBJECT (message), "response", G_CALLBACK (gtk_widget_destroy), G_OBJECT (message));
 			gtk_widget_show(message);
 	}
@@ -416,6 +417,7 @@ bool gcpSelectionTool::OnRightButtonClicked (GtkUIManager *UIManager)
 			for (type = wrong_types.begin(); type != wrong_types.end (); type++)
 				possible_types.erase (*type);
 			wrong_types.clear ();
+			types.clear ();
 		}
 		if (possible_types.size () == 1) {
 			// Add a new action.
