@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2003
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -66,6 +66,7 @@ static void on_load(gpointer p, Bonobo_Stream stream, const Bonobo_Persist_Conte
 	Bonobo_Stream_iobuf*  buffer;
 	Bonobo_Stream_read(stream, l, &buffer, ev);
 	char buf[l+1];
+
 	memcpy(buf, buffer->_buffer, l);
 	buf[l] = 0;
 	xmlDocPtr xml = NULL;
@@ -109,6 +110,7 @@ static void on_save(gpointer p, Bonobo_Stream stream, const Bonobo_Persist_Conte
 
 static PersistStream* persist_stream_new()
 {
+
 	PersistStream* ps = (PersistStream*) g_object_new (PERSIST_STREAM_TYPE, NULL);
 	return ps;
 }
@@ -134,7 +136,7 @@ static void persist_stream_class_init(PersistStreamClass *klass)
 
 enum {
 	PROP_BGCOLOR,
-	PROP_EDITABLE
+//	PROP_EDITABLE
 };
 
 static void get_prop(BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, CORBA_Environment *ev, GtkWidget *widget)
@@ -148,12 +150,12 @@ static void get_prop(BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, CORBA
 			g_object_get(G_OBJECT(pData->Background), "fill_color", &str, NULL);
 			BONOBO_ARG_SET_STRING(arg, str);
 			break;
-		case PROP_EDITABLE:
+/*		case PROP_EDITABLE:
 			{
 				gcpDocument* pDoc = (gcpDocument*) g_object_get_data(G_OBJECT(widget), "doc");
 				BONOBO_ARG_SET_BOOLEAN(arg, (pDoc)? pDoc->GetEditable(): false);
 			}
-			break;
+			break;*/
 		default:
 			bonobo_exception_set(ev, ex_Bonobo_PropertyBag_NotFound);
 			break;
@@ -168,11 +170,11 @@ static void set_prop (BonoboPropertyBag *bag,  const BonoboArg *arg, guint arg_i
 		case PROP_BGCOLOR:
 			g_object_set(G_OBJECT(pData->Background), "fill_color", BONOBO_ARG_GET_STRING(arg));
 			break;
-		case PROP_EDITABLE:
+/*		case PROP_EDITABLE:
 			{
 				gcpDocument* pDoc = (gcpDocument*) g_object_get_data(G_OBJECT(widget), "doc");
 				if (pDoc) pDoc->SetEditable(BONOBO_ARG_GET_BOOLEAN(arg));
-			}
+			}*/
 			break;
 		default:
 			bonobo_exception_set(ev, ex_Bonobo_PropertyBag_NotFound);
@@ -235,7 +237,7 @@ void gcp_bonobo_set_state(gpointer data, const char *id, const char *state)
 	for (i = ActiveControls.begin(); i != ActiveControls.end(); i++)
 		if (*i != data)
 			bonobo_ui_component_set_prop((*i)->uic, id, "state", state, NULL);
-#warning "FIXME: use data to get active tool"
+//#warning "FIXME: use data to get active tool"
 /*	if ((!strcmp(id, "/commands/ViewTools")) && (!strcmp(state, "0")) && pActiveTool)
 	{
 		pActiveTool->Deactivate();
@@ -459,6 +461,7 @@ gcpBonoboControl* gcp_bonobo_control_construct(gcpBonoboControl *control, gcpDoc
 	g_return_val_if_fail (GCP_BONOBO_IS_CONTROL (control), NULL);
 
 	widget = pDoc->GetView()->CreateNewWidget();
+	pDoc->SetEditable (false);
 
 	bonobo_control_construct (BONOBO_CONTROL (control), widget);
 	pb = bonobo_property_bag_new( 
@@ -472,10 +475,10 @@ gcpBonoboControl* gcp_bonobo_control_construct(gcpBonoboControl *control, gcpDoc
 				 BONOBO_ARG_STRING, NULL,
 				 _("Background color"),
 				 0);
-	bonobo_property_bag_add(pb, "bonobo:editable", PROP_EDITABLE,
+/*	bonobo_property_bag_add(pb, "bonobo:editable", PROP_EDITABLE,
 				 BONOBO_ARG_BOOLEAN, NULL,
 				 _("Editable file flag"),
-				 TRUE);
+				 FALSE);*/
 	
 	control->ps = persist_stream_new();
 	control->ps->pDoc = pDoc;
@@ -510,16 +513,11 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 	gcpBonoboApp* App = new gcpBonoboApp();
 	gcpDocument* pDoc =  new gcpDocument(App, false);
 	if (!pDoc) return NULL;
-	if (!strcmp (component_id, "OAFIID:gchempaint_control"))
+	if (!strcmp (component_id, "OAFIID:gchempaint_unstable_control"))
 	{
 		retval = (BonoboObject*) gcp_bonobo_control_new(pDoc);
 		if (!retval)  delete pDoc;
 	}
-	else if (!strcmp (component_id, "OAFIID:gchempaint_item"))
-	{
-		g_warning ("GChemPaint Item is not implemented yet");
-		return NULL;
-	}
 	else
 	{
 		g_warning ("Unknown IID `%s' requested", component_id);
@@ -532,4 +530,12 @@ BonoboObject * gchempaint_factory(BonoboGenericFactory * fact, const char *compo
 
 int main (int argc, char *argv[])
 {
+	bindtextdomain(PACKAGE, DATADIR"/locale");
+#ifdef ENABLE_NLS
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
+	textdomain(PACKAGE);
+	gtk_init (&argc, &argv);
+	BONOBO_FACTORY_INIT ("gchempaint_unstable", VERSION, &argc, argv);		
+	return bonobo_generic_factory_main ("OAFIID:gchempaint_unstable_factory", gchempaint_factory, NULL);
 }
